__package__='' # workaround for PEP 366

import univention.management.console.modules.oxldb.oxldbcore as modoxldb
import univention.config_registry
import univention.lib

_ = univention.lib.Translation('univention-management-console-module-oxldb-hook').translate

ox_problem_detected = False
block_oxse = False

configRegistry = univention.config_registry.ConfigRegistry()
configRegistry.load()


def get_ox_status():
	global block_oxse
	block_oxse = False
	msg = None

	oxldb = modoxldb.OXLDB(connect=True)

	if not oxldb.is_account_complete():
		msg = _('The Open-Xchange LDB account has not been specified yet. The account is required for installing updates.')
	elif not oxldb.is_account_valid():
		msg = _('The Open-Xchange LDB account seems to be invalid. Please check given credentials. The account is required for installing updates.')
	elif not oxldb.get_keys(products=oxldb.detected_products):
		msg = _('There is no %s license key associated with specified Open-Xchange LDB account.') % oxldb.get_productname_short()
	elif not oxldb.licensekey or not oxldb.licensekey in oxldb.get_keys(products=oxldb.detected_products):
		msg = _('No Open-Xchange license key has been selected or the selected license key does not match to the specified Open-Xchange LDB account.')
		block_oxse = True
	elif oxldb.ldb_eula_get_url() and not oxldb.ldb_eula_has_been_accepted():
		msg = _('Enduser license agreement (EULA) of %s has not been accepted yet.') % oxldb.get_productname_short()

	return msg


def updater_show_message(*args, **kwargs):
	global ox_problem_detected

	msg = get_ox_status()
	ox_problem_detected = bool(msg)

	result = { 'valid': False }
	if ox_problem_detected:
		result['valid'] = True
		result['title'] = _('Open-Xchange license information'),
		result['message'] = """<p>%s</p><p><a href='javascript:dojo.publish("/umc/modules/open", ["oxldb"]);'>""" % msg + _('Switch to license management module') + '</a></p>'

	return result


def updater_prohibit_update(*args, **kwargs):
	global ox_problem_detected
	if not block_oxse:
		return False
	return ox_problem_detected


def update_finished(*args, **kwargs):
	univention.config_registry.handler_set( [ 'update/reboot/required=yes' ] )
	return None


def register_hooks():
	return [ ('updater_show_message', updater_show_message),
			 ('updater_prohibit_update', updater_prohibit_update),
			 ('update_finished', update_finished),
			 ]
